@@ -55,7 +55,7 @@ import "strings"
 	name:       string & =~"^(([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9])?$" & strings.MaxRunes(63) & strings.MinRunes(1)
 	instances: [string & =~"^(([A-Za-z0-9][-A-Za-z0-9_.]*)?[A-Za-z0-9])?$" & strings.MaxRunes(63) & strings.MinRunes(1)]: {
 		module: close({
-			url:     string & =~"^oci://.*$"
+			url:     string & =~"^(oci|file)://.*$"
 			version: *"latest" | string
 			digest?: string
 		})
